document.addEventListener('DOMContentLoaded', () => {
    // Scroll-based background change for header and menu
    const header = document.getElementById('header');
    const menu = document.getElementById('menu');
    const logo = document.getElementById('logo');

    // Add an event listener for scrolling
    window.addEventListener('scroll', function() {
      if (window.scrollY > 50) { // Apply to all screen sizes
        header.classList.add('scroll-background');
        menu.classList.add('scroll-background');
        logo.classList.add('shrink'); // Add the shrink class to the logo
      } else {
        header.classList.remove('scroll-background');
        menu.classList.remove('scroll-background');
        logo.classList.remove('shrink'); // Remove the shrink class from the logo
      }
    });

    // GSAP Animations
   

    // GSAP for sliding menu animation with overlay
    const menuIcon = document.getElementById('menuIcon');
    const overlay = document.getElementById('overlay');
    let isOpen = false;

    // Toggle menu and overlay visibility
    function toggleMenu() {
      if (isOpen) {
        gsap.to(menu, { right: '-100%', duration: 0.5, ease: 'power2.out' });
        gsap.to(overlay, { opacity: 0, duration: 0.5, ease: 'power2.out', onComplete: () => overlay.style.pointerEvents = 'none' });
        menuIcon.classList.remove('open');
      } else {
        gsap.to(menu, { right: 0, duration: 0.5, ease: 'power2.out' });
        gsap.to(overlay, { opacity: 0.5, duration: 0.5, ease: 'power2.out', onStart: () => overlay.style.pointerEvents = 'auto' });
        menuIcon.classList.add('open');
      }
      isOpen = !isOpen;
    }

    // Event listener for menu icon click
    menuIcon.addEventListener('click', (e) => {
      e.stopPropagation(); // Prevent click from propagating to the document
      toggleMenu();
    });

    // Event listener for overlay click
    overlay.addEventListener('click', () => {
      if (isOpen) {
        toggleMenu();
      }
    });

    // Event listener for clicks outside the menu
    document.addEventListener('click', (e) => {
      if (isOpen && !menu.contains(e.target) && !menuIcon.contains(e.target)) {
        toggleMenu();
      }
    });
});
