<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>Silverleaf</title>
  <link rel="stylesheet" href="<?php echo e(asset('css/homestyle.css')); ?>">
  <script>
    document.addEventListener('DOMContentLoaded', function() {
          const currentYear = new Date().getFullYear();

          // Check if age verification was already completed using localStorage
          if (localStorage.getItem('ageVerified') === 'true') {
              // If already verified, show the main content directly
              document.getElementById('age-form-overlay').style.display = 'none';
              gsap.to("#main-content", {opacity: 1, duration: 1, display: "block"});
          }

          // Real-time input validation for day, month, and year
          document.getElementById('day').addEventListener('input', function() {
              const day = parseInt(this.value, 10);
              if (day < 1 || day > 31 || isNaN(day)) {
                  this.value = ''; // Clear invalid input
                  showDayError('Day must be between 1 and 31');
              } else {
                  hideDayError();
              }
          });

          document.getElementById('month').addEventListener('input', function() {
              const month = parseInt(this.value, 10);
              if (month < 1 || month > 12 || isNaN(month)) {
                  this.value = ''; // Clear invalid input
                  showMonthError('Month must be between 1 and 12');
              } else {
                  hideMonthError();
              }
          });

          document.getElementById('year').addEventListener('input', function() {
              const year = parseInt(this.value, 10);
              if (year < 0 || year > currentYear || isNaN(year)) {
                  this.value = ''; // Clear invalid input
                  showYearError(`Year must be between 1900 and ${currentYear}`);
              } else {
                  hideYearError();
              }
          });

          // Button click event handler for validation
          document.querySelector('#age-form button').addEventListener('click', function() {
              const day = parseInt(document.getElementById('day').value, 10);
              const month = parseInt(document.getElementById('month').value, 10);
              const year = parseInt(document.getElementById('year').value, 10);

              if (!day || !month || !year) {
                  if (!day) showDayError('Day is required');
                  if (!month) showMonthError('Month is required');
                  if (!year) showYearError('Year is required');
                  return;
              }

              // Calculate the user's age
              const today = new Date();
              const birthDate = new Date(year, month - 1, day);
              let age = today.getFullYear() - birthDate.getFullYear();
              const monthDiff = today.getMonth() - birthDate.getMonth();

              if (monthDiff < 0 || (monthDiff === 0 && today.getDate() < birthDate.getDate())) {
                  age--;
              }

              if (age >= 18) {
                  document.getElementById('age-form-overlay').style.display = 'none';
                  // Store a flag in localStorage to mark that the user has passed age verification
                  localStorage.setItem('ageVerified', 'true');
                  // GSAP animation for main content with a callback to refresh the page after the animation
                  location.reload();
                  gsap.to("#main-content", {
                      opacity: 1,
                      duration: 0,
                      display: "block",
                      onComplete: function() {
                          // Refresh the page after the animation is complete

                      }
                  });
              } else {
                  showYearError('You must be at least 18 years old to enter.');
              }
          });

          // Functions to show/hide error messages
          function showDayError(message) {
              const errorElement = document.querySelector('.error-message');
              errorElement.textContent = message;
              errorElement.style.display = 'block';
          }
          function hideDayError() {
              document.querySelector('.day-error-message').style.display = 'none';
          }

          function showMonthError(message) {
              const errorElement = document.querySelector('.error-message');
              errorElement.textContent = message;
              errorElement.style.display = 'block';
          }
          function hideMonthError() {
              document.querySelector('.error-message').style.display = 'none';
          }

          function showYearError(message) {
              const errorElement = document.querySelector('.error-message');
              errorElement.textContent = message;
              errorElement.style.display = 'block';
          }
          function hideYearError() {
              document.querySelector('.error-message').style.display = 'none';
          }
      });
</script>

  <?php echo $__env->make('user.header', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
</head>
<body>
    <div id="age-form-overlay">
        <div id="age-form">
            <div class="ageloginhd">
                <img src="<?php echo e(asset('img/wlogo.png')); ?>" alt="">
                <div class="ageloginline">
                    <h2>LIVE FREELY. DRINK RESPONSIBLY</h2>
                </div>
            </div>

            <div class="ageloginhead">
                <img class="img1" src="<?php echo e(asset('img/ageloginleaf.png')); ?>" alt="">
                <p>Enter your date of birth</p>
                <img class="img2" src="<?php echo e(asset('img/ageloginleaf.png')); ?>" alt="">
            </div>

            <input type="number" id="day" placeholder="DD" min="1" max="31" required>


            <input type="number" id="month" placeholder="MM" min="1" max="12" required>

            <input type="number" id="year" placeholder="YYYY" min="0" max="2024" required>

            <br>
            <button>Enter</button>
            <div class="error-message "></div>


        </div>
    </div>

    <!-- Content of the site -->
    <div id="main-content">

    <?php echo $__env->make('user.nav', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>


  <!-- Full-screen section -->
  <div class="container-fluid container-box first-container" id="section1">
    <div class="row flex-column-reverse flex-md-row">
      <!-- Title and Description Column -->
      <div class="col-12 col-md-6 order-1 order-md-1">
        <h1 id="title">Explore The Enchanted Silverleaf Gin</h1>
        <p id="description">Silverleaf gin is a testament to Singapore's unique botanical landscape. At the heart of every bottle lies the extraordinary essence of locally grown ice plants. This unprecedented ingredient, combined with meticulous craftsmanship, creates a gin unlike any other.</p>
        <a  href="<?php echo e(route('user.about')); ?>" class="button">
          Discover more &nbsp;
          <div class="arrow-fcontainer">
            <div class="fline"></div>
            <div class="ftriangle"></div>
          </div>
        </a>
      </div>

      <!-- Bottle Image Column -->
      <div class="col-12 col-md-6 order-1 order-md-1">
        <div class="container-fluidbottle">
          <!-- Bottle Image -->
          <img src="<?php echo e(asset('img/Mask group.png')); ?>" alt="Bottle" class="bottle-image" />
          <!-- Leaf Images -->
          <img src="<?php echo e(asset('img/2.png')); ?>" alt="Leaf 1" class="leaf-image leaf1" />
          <img src="<?php echo e(asset('img/3.png')); ?>" alt="Leaf 2" class="leaf-image leaf2" />
          <img src="<?php echo e(asset('img/4.png')); ?>" alt="Leaf 3" class="leaf-image leaf3" />
          <!-- Fruit Image -->
          <img src="<?php echo e(asset('img/black-berry.png')); ?>" alt="Fruit" class="fruit-image" />
          <!-- Bottle Cap Image -->
          <a href="#section2">  <img src="<?php echo e(asset('img/bottle cap.png')); ?>" alt="Cap" class="cap-image" /></a>
          <img src="<?php echo e(asset('img/caphead.png')); ?>" alt="Cap" class="caphead-image" />
          <!-- <div class="opentext">Open to Explore</div> -->
<a href="#section2" class="opentext">Open to Explore</a>
        </div>
      </div>
    </div>

  </div>
   <img class="intbg1" src="<?php echo e(asset('img/cherry.png')); ?>" alt="">

  <div class="container-fluid product-showcase-body second-container" id="section2">
    <!-- <div class="product-showcase-body"> -->

        <div class="product-showcase-container">
            <!-- Centered Heading -->
            <h1 class="centered-heading" id="centered-heading">Delve into the <br>
                Wonders of the Silverleaf</h1>

            <!-- Left side: bottle with leaf background -->
            <div class="left-side">
                <img src="<?php echo e(asset('img/silder_leaf_1.png')); ?>" alt="Leaf" class="leaf">
                <img src="<?php echo e(asset('img/silder_bottle_1.png')); ?>" alt="Bottle" class="bottle">
            </div>

            <!-- Right side: text and boxes -->
            <div class="right-side">
                <h1>ENIGMA</h1>
                <h2>CONTEMPORAY GIN</h2>
                <p>A refreshing and unique spirit that captures the essence of nature. Crafted with handpicked iceplant, this gin boasts a crisp and clean flavor profile with a hint of coastal freshness. Perfect for a chilled martini or a classic gin and tonic, Iceplant Gin is a testament to our dedication to quality and innovation.
                <div class="boxes">
                    <div class="box">
                        <p>Ice Plant</p>
                        <img src="<?php echo e(asset('img/Ice Plant BG.png')); ?>" alt="Icon 1">

                    </div>
                    <div class="box">
                        <p>Juniper</p>
                        <img src="<?php echo e(asset('img/Juniper berry BG.png')); ?>" alt="Icon 2">

                    </div>
                    <div class="box">
                        <p>Coriander</p>
                        <img src="<?php echo e(asset('img/Coriander BG.png')); ?>" alt="Icon 3">

                    </div>
                    <div class="box">
                        <p>Kombu</p>
                        <img src="<?php echo e(asset('img/Kombu BG.png')); ?>" alt="Icon 4">

                    </div>
                    <div class="box">
                        <p>Anglica</p>
                        <img src="<?php echo e(asset('img/Angelica BG.png')); ?>" alt="Icon 5">

                    </div>
                    <div class="box">
                        <p>Schisandra</p>
                        <img src="<?php echo e(asset('img/Schisandra BG.png')); ?>" alt="Icon 6">

                    </div>
                </div>
            </div>

            <!-- Navigation arrows -->
            <div class="nav-arrow left" onclick="previousContent()">&#10094;</div>
            <div class="nav-arrow right" onclick="nextContent()">&#10095;</div>
        </div>

   <script>
    // contentSlider.js
// contentSlider.js

let currentContent = 0;
const totalSets = 3;

const contentData = [
  {
    bottleImage: '<?php echo e(asset('img/silder_bottle_1.png')); ?>',
    leafImage: '<?php echo e(asset('img/silder_leaf_1.png')); ?>',
    heading: 'ENIGMA',
    subheading: 'CONTEMPORAY GIN',
    paragraph: 'A refreshing and unique spirit that captures the essence of nature. Crafted with handpicked iceplant, this gin boasts a crisp and clean flavor profile with a hint of coastal freshness. Perfect for a chilled martini or a classic gin and tonic, Iceplant Gin is a testament to our dedication to quality and innovation.',
    boxes: [
      { name: 'Ice Plant', image: '<?php echo e(asset('img/Ice Plant BG.png')); ?>' },
      { name: 'Juniper', image: '<?php echo e(asset('img/Juniper berry BG.png')); ?>' },
      { name: 'Coriander', image: '<?php echo e(asset('img/Coriander BG.png')); ?>' },
      { name: 'Kombu', image: '<?php echo e(asset('img/Kombu BG.png')); ?>' },
      { name: 'Anglica', image: '<?php echo e(asset('img/Angelica BG.png')); ?>' },
      { name: 'Schisandra', image: '<?php echo e(asset('img/Schisandra BG.png')); ?>' },
    ],
    leafAngle: 17,
    bottleAngle: -28,
    centerHeading: 'Delve into the  Wonders of the Silverleaf'
  },
  {
    bottleImage: '<?php echo e(asset('img/silder_bottle_2.png')); ?>',
    leafImage: '<?php echo e(asset('img/silder_leaf_2.png')); ?>',
    heading: 'MIRAGE',
    subheading: 'CONTEMPORAY GIN',
    paragraph: 'This exquisite gin blends the crisp, coastal essence of iceplant with the exotic, multifaceted flavors of schisandra berries. The result is a vibrant, refreshing spirit that offers a harmonious balance of tart, sweet, and earthy notes. This innovative blend promises a unique and captivating taste experience.',
    boxes: [
        { name: 'Ice Plant', image: '<?php echo e(asset('img/Ice Plant BG.png')); ?>' },
      { name: 'Juniper', image: '<?php echo e(asset('img/Juniper berry BG.png')); ?>' },
      { name: 'Coriander', image: '<?php echo e(asset('img/Coriander BG.png')); ?>' },
      { name: 'Kombu', image: '<?php echo e(asset('img/Kombu BG.png')); ?>' },
      { name: 'Anglica', image: '<?php echo e(asset('img/Angelica BG.png')); ?>' },
      { name: 'Schisandra', image: '<?php echo e(asset('img/Schisandra BG.png')); ?>' },
    ],
    leafAngle: -16,
    bottleAngle: 29,
    centerHeading: 'Delve into the Wonders of the Silverleaf'
  },
  {
    bottleImage: '<?php echo e(asset('img/silder_bottle_3.png')); ?>',
    leafImage: '<?php echo e(asset('img/silder_leaf_1.png')); ?>',
    heading: 'MIRAGE GOLD',
    subheading: 'CONTEMPORAY GIN',
    paragraph: 'Indulge in opulence with Silverleaf Mirage Gold. This extraordinary gin, crafted in Singapore, is a masterpiece of flavor and design. Infused with ice plants, schisandra and adorned with edible gold leaf, it delivers a truly unforgettable sensory experience. A harmonious blend of classic juniper and exotic botanicals creates a luxurious spirit that embodies sophistication.',
    boxes: [
        { name: 'Ice Plant', image: '<?php echo e(asset('img/Ice Plant BG.png')); ?>' },
      { name: 'Juniper', image: '<?php echo e(asset('img/Juniper berry BG.png')); ?>' },
      { name: 'Coriander', image: '<?php echo e(asset('img/Coriander BG.png')); ?>' },
      { name: 'Kombu', image: '<?php echo e(asset('img/Kombu BG.png')); ?>' },
      { name: 'Anglica', image: '<?php echo e(asset('img/Angelica BG.png')); ?>' },
      { name: 'Schisandra', image: '<?php echo e(asset('img/Schisandra BG.png')); ?>' },
    ],
    leafAngle: 5,
    bottleAngle: -24,
    centerHeading: 'Delve into the Wonders of the Silverleaf'
  }
];


function nextContent() {
  currentContent = (currentContent + 1) % totalSets;
  updateContent();
}

function previousContent() {
  currentContent = (currentContent - 1 + totalSets) % totalSets;
  updateContent();
}

function updateContent() {
  const bottleImage = document.querySelector('.bottle');
  const leafImage = document.querySelector('.leaf');
  const heading = document.querySelector('.right-side h1');
  const subheading = document.querySelector('.right-side h2');
  const paragraph = document.querySelector('.right-side p');
  const boxes = document.querySelectorAll('.box p');
  const boxImages = document.querySelectorAll('.box img');
  const centeredHeading = document.getElementById('centered-heading');

  const content = contentData[currentContent];

  // Opacity fade-out
  document.querySelector('.left-side').style.opacity = '0';
  document.querySelector('.right-side').style.opacity = '0';
  centeredHeading.style.opacity = '0';

  // Delay for smooth transition
  setTimeout(() => {
    // Update images and text content
    bottleImage.src = content.bottleImage;
    leafImage.src = content.leafImage;
    heading.textContent = content.heading;
    subheading.textContent = content.subheading;
    paragraph.textContent = content.paragraph;

    // Apply the specific rotation angles
    bottleImage.style.transform = `rotate(${content.bottleAngle}deg)`;
    leafImage.style.transform = `rotate(${content.leafAngle}deg)`;

    // Update centered heading
    centeredHeading.textContent = content.centerHeading;

    // Update boxes content
    boxes.forEach((box, index) => {
      box.textContent = content.boxes[index].name;
      boxImages[index].src = content.boxes[index].image;
    });

    // Opacity fade-in
    document.querySelector('.left-side').style.opacity = '1';
    document.querySelector('.right-side').style.opacity = '1';
    centeredHeading.style.opacity = '1';
  }, 500); // Delay matches the transition timing
}

// Initialize content on page load
updateContent();

   </script>
    <!-- </div> -->

  </div>
  <img class="intbg2" src="<?php echo e(asset('img/intbg2.png')); ?>" alt="">
  <div class="containerthree">
        <div class="column column1">
            <span class="span1">“</span>
           <p> “The absolute attention to detail” is simply about maintaining the standard of our gin.</p>
           <span class="span2">”</span>
            <img src="<?php echo e(asset('img/threecontainerfirstbg.png')); ?>" alt="">
        </div>
        <div class="column column2">
            <div><span class="span1">&</span><span class="span2">How</span></div>
            <img class="clogo" src="<?php echo e(asset('img/blogo.png')); ?>" alt="">
           <p> come to this?</p>
            <img class="threeconcol2img" src="<?php echo e(asset('img/threecontainersecondbg.png')); ?>" alt="">

        </div>
        <div class="column column3">
            <h1>About US</h1>
            <p>
            Silverleaf gin is a testament to Singapore's unique botanical landscape. at the heart of every bottle lies the extraordinary essence of locally grown ice plants. this unprecedented ingredient, combined with meticulous craftsmanship, creates a gin unlike any other.
        </p>
        <a href="<?php echo e(route('user.about')); ?>" class="thrbutton">
            Discover more &nbsp;
            <div class="arrow-fcontainer">
              <div class="fline"></div>
              <div class="ftriangle"></div>
            </div>
          </a>
        </div>
    </div>
    <img class="intbg3" src="<?php echo e(asset('img/feling_content.png')); ?>" alt="">
<div class="sliderfour">
    <div class="silder2heading">
        <img class="img1" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt="">
        <p>A New Cocktail Experience</p>
        <img class="img2" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt="">
    </div>

    <!-- Original static design for larger screens (laptop/desktop) -->
    <div class="slider2silder-static">
        <div class="silder2slide-static">
            <img src="<?php echo e(asset('img/silder2img1.png')); ?>" alt="Image 1">
            <a style="text-decoration: none" href="<?php echo e(route('user.cocktail')); ?>">     <div class="silder2overlay-static">
                <h3>Calamansi Martini Twist</h3>
                <p>Silverleaf Gin 60ml Calamansi juice 15ml Agave syrup 15ml Splash of tonic Shaken.</p>
                <div class="arrow-fcontainer">
                    <div class="fline"></div>
                    <div class="ftriangle"></div>
                  </div>
            </div></a>
        </div>

        <div class="silder2slide-static">
            <img src="<?php echo e(asset('img/silder2img2.png')); ?>" alt="Image 2">
            <a style="text-decoration: none" href="<?php echo e(route('user.cocktail')); ?>">     <div class="silder2overlay-static">
                <h3>Spicy Peach Highball</h3>
                <p>Peach Puree 30ml Lemon Juice 20ml Chili Pepper Liqueur 10ml Silver Leaf Gin 40ml Soda top up Salt rim Shaken</p>
                <div class="arrow-fcontainer">
                    <div class="fline"></div>
                    <div class="ftriangle"></div>
                  </div>
            </div></a>
        </div>

        <div class="silder2slide-static">
            <img src="<?php echo e(asset('img/silder2img3.png')); ?>" alt="Image 3">
            <a style="text-decoration: none" href="<?php echo e(route('user.cocktail')); ?>">  <div class="silder2overlay-static">
                <h3>Cassis Cherry Bliss</h3>
                <p>Ice Plant Gin 45ml Creme De Cassis 10ml Cherry Liquer 5ml Sour Prune 1 piece. Shaken</p>
                <div class="arrow-fcontainer">
                    <div class="fline"></div>
                    <div class="ftriangle"></div>
                  </div>
            </div></a>
        </div>
    </div>

    <!-- Slider only visible on mobile/tablet views -->
    <div class="slider2silder" id="slider">
        <div class="silder2slide active">
            <img src="<?php echo e(asset('img/silder2img1.png')); ?>" alt="Image 1">
            <div class="silder2overlay">
                <h3>Calamansi Martini Twist</h3>
                <p>Silverleaf Gin 60ml Calamansi juice 15ml Agave syrup 15ml Splash of tonic Shaken.</p>
                <div class="arrow-fcontainer">
                    <div class="fline"></div>
                    <div class="ftriangle"></div>
                  </div>
            </div>

        </div>

        <div class="silder2slide">
            <img src="<?php echo e(asset('img/silder2img2.png')); ?>" alt="Image 2">
            <div class="silder2overlay">
                <h3>Spicy Peach Highball</h3>
                <p>Peach Puree 30ml Lemon Juice 20ml Chili Pepper Liqueur 10ml Silver Leaf Gin 40ml Soda top up Salt rim Shaken</p>
                <div class="arrow-fcontainer">
                    <div class="fline"></div>
                    <div class="ftriangle"></div>
                  </div>
            </div>
        </div>

        <div class="silder2slide">
            <img src="<?php echo e(asset('img/silder2img3.png')); ?>" alt="Image 3">
            <div class="silder2overlay">
                <h3>Cassis Cherry Bliss</h3>
                <p>Ice Plant Gin 45ml Creme De Cassis 10ml Cherry Liquer 5ml Sour Prune 1 piece. Shaken</p>
                <div class="arrow-fcontainer">
                    <div class="fline"></div>
                    <div class="ftriangle"></div>
                  </div>
            </div>
        </div>

        <!-- Slider navigation buttons -->
        <a class="fprev" onclick="moveSlide(-1)"></a>
        <a class="fnext" onclick="moveSlide(1)"></a>
    </div>

    <script>
        let currentIndex2 = 0;
        const slides = document.querySelectorAll('.silder2slide');

        function moveSlide(direction) {
            slides[currentIndex2].classList.remove('active');
            currentIndex2 += direction;

            if (currentIndex2 >= slides.length) {
                currentIndex2 = 0;
            } else if (currentIndex2 < 0) {
                currentIndex2 = slides.length - 1;
            }

            slides[currentIndex2].classList.add('active');
        }

        function autoSlide() {
            moveSlide(1);
        }

        // Change slide every 5 seconds
        let slideInterval = setInterval(autoSlide, 5000);

        // Stop auto-slide on manual navigation
        document.querySelector('.fprev').addEventListener('click', () => {
            clearInterval(slideInterval);
            moveSlide(-1);
        });

        document.querySelector('.fnext').addEventListener('click', () => {
            clearInterval(slideInterval);
            moveSlide(1);
        });
    </script>

</div>
<img class="intbg4" src="<?php echo e(asset('img/blue_berry.png')); ?>" alt="">
<div class="sliderhomelast">
    <div class="silderlastheading">
        <img class="img1" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt="">
        <p>Sliverleaf on News</p>
        <img class="img2" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt="">
    </div>
    <div class="slider">
        <div class="left-content">
            <div class="leftbg">
                <div><img class="imageset1" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt=""></div>
                <div><img class="imageset2" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt=""></div>
                <div><img class="imageset3" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt=""></div>
                <div><img class="imageset4" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt=""></div>
                <div><img class="imageset5" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt=""></div>
                <div><img class="imageset6" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt=""></div>
                <div><img class="imageset7" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt=""></div>
                <div><img class="imageset8" src="<?php echo e(asset('img/codeleaf.png')); ?>" alt=""></div>
                <div class="dotted-linetop"></div>
                <div class="dotted-lineright"></div>
                <div class="dotted-linebottom"></div>
                <div class="dotted-lineleft"></div>
                <img class="mainimg" id="mainimg" src="<?php echo e(asset('img/silderlasthome1.png')); ?>" alt="Overlay Image">
            </div>
        </div>
        <div class="right-content">
            <h1 class="title1" id="title1">The evolving drinking habits of the new generation</h1>
            <h2 class="title2" id="title2">Times of  London</h2>
            <p class="titledate" id="date">March 1 | 2022</p>
            <a href="<?php echo e(route('user.news')); ?>" class="button">
                Discover more &nbsp;
                <div class="arrow-fcontainer">
                    <div class="fline"></div>
                    <div class="ftriangle"></div>
                </div>
            </a>
        </div>

    </div>
    <button class="arrow left" onclick="prevSlide()"></button>
    <button class="arrow right" onclick="nextSlide()"></button>
    <script>
        const images = [
            { img: '<?php echo e(asset('img/silderlasthome1.png')); ?>', title1: 'The evolving drinking habits of the new generation', title2: 'Times of  London', date: 'March 1 | 2022' },
            { img: '<?php echo e(asset('img/silderlasthome1.png')); ?>', title1: 'The evolving drinking habits of the new generation', title2: 'Times of  London', date: 'March 10 | 2022' },
            { img: '<?php echo e(asset('img/silderlasthome1.png')); ?>', title1: 'The evolving drinking habits of the new generation', title2: 'Times of  London', date: 'March 21 | 2022' }
        ];

        let currentIndex = 0;

        function showSlide(index) {
            const totalSlides = images.length;
            if (index >= totalSlides) {
                currentIndex = 0;
            } else if (index < 0) {
                currentIndex = totalSlides - 1;
            } else {
                currentIndex = index;
            }

            const { img, title1, title2, date } = images[currentIndex];

            document.getElementById('mainimg').src = img;
            document.getElementById('title1').textContent = title1;
            document.getElementById('title2').textContent = title2;
            document.getElementById('date').textContent = date;
        }

        function nextSlide() {
            showSlide(currentIndex + 1);
        }

        function prevSlide() {
            showSlide(currentIndex - 1);
        }
    </script>
</div>
<?php echo $__env->make('user.footer', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
<?php echo $__env->make('user.homefooter', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?>
    </div>

</body>
</html>
<?php /**PATH R:\GIn-laravel\silverleaf\resources\views/user/index.blade.php ENDPATH**/ ?>